## Summary

This is an extension of Maike Kleemeyer's dcms2nifti matlab scripts to create MPM maps and run the hMRI pipeline.
There are similar, individual stages. They must be individually started **and
waited for**! Each stage will create batch and save files and logs.  The
batches for each stage are created and submitted with:

#### 0. Prerequisite

Edit the user specific section of [setup_paths.m](setup_paths.m) to set input/output folders and point to your SPM12 (with
hMRI, see Build Section or get a copy from Michael).

#### 1.1 import Dicom files
**dcms2nifti.m**
```
module load matlab/R2017b # if not done already
matlab -r 'dcms2nifti; quit'
```

#### 1.2 merge duplicate `_1` sessions
**merge_data.m**:
```
module load matlab/R2017b # if not done already
matlab -r 'merge_data; quit'
```

#### 2. Reorient
**reorient.m**:
```
module load matlab/R2017b # if not done already
matlab -r 'reorient; quit'
```

#### 3. create maps
**createmaps.m**:
```
module load matlab/R2017b # if not done already
matlab -r 'createmaps; quit'
```

#### 4. hmri.proc.proc_pipel
**processmaps.m**:
```
module load matlab/R2017b # if not done already
matlab -r 'processmaps; quit'
```

Each script will not submit a job again, when some known output file already
exists. Check the source for the individual checks.

To start over, delete (some) outputfiles for a specific subject and run a stage again. For instance:

```
rm -rf output/derivatives/MPM/sub-*/ses-*/reorient*
rm -rf output/derivatives/MPM/sub-*/ses-*/qMRI*
```

## Questions

Collection of open issues/questions about this set of scripts. Could be moved to an actual issue tracker..

**TODO**

**Open**

+ for processmaps with MT source I got this error:

```
Contents of 'proc_pipel' does not meet check criteria:
'Number of maps not matching number of structural images/subjects!

```
I opted for `spm_select(... '^.*01\.nii$')`


**Done**

+ removed Maike's initial batches `preprocessing/Dicoms/\*batches`

+ results synchronized to:
  - `EnergI/preprocessing/Niftis/MPM/rawdata`
  - `EnergI/processing/MRI/MPM/derivatives`

+ remove `preprocessing/Nifits/GRE_field/\*`

+ fixed `AKTIV2251C` naming issue and resynced dicom data

+ b0 order in stage2 is important

+ also import MPrage_3Ddist

+ magnitude/phase wrong order

+ stage3 is single subject (first line)
  + s_vols for MPrage und MT each

+ B1mapping/AKTIV* ?= MT/AKTIV* ?= PD/AKTIV* ?= GRE_FIELD/AKTIV* ...

+ What to do with two-scan sequences ?
   + `sub-AKTIV*_rec-1_T1w.nii.gz` ?
   + `sub-AKTIV*_run-1_T1w.nii.gz` ?
   + `sub-AKTIV*_acq-1_T1w.nii.gz` ?

  phase and magnitude
  (`dicominfo()` to check)

+ Should output folder structure match Nifti import?

   new import can be the new reference folder

+ `matlabbatch{1}.spm.util.import.dicom.convopts.meta = true;` for sidecar files - not in hMRI !?

  BIDS doesn't matter

+ Why `ext`?  https://mpib.berlin/2KIHu

    `sepext` should work as well

## Build

**Attention**: Currently it's not possible to run the map processing pipeline
with a compiled batch. This might get fixed at some point however. It's
entirely possibe to run the batches in regular matlab sessions, given there are
enough free licenses.

For all other steps, you should build a compiled spm12+hmri:

1. Download and extract [spm12](https://www.fil.ion.ucl.ac.uk/spm/download/restricted/eldorado/spm12.zip)

Example:
```
wget https://www.fil.ion.ucl.ac.uk/spm/download/restricted/eldorado/spm12.zip
unzip spm12.zip
mkdir -p $HOME/matlab/tools
mv spm12 $HOME/matlab/tools/spm12_hmri
# optionally clean up pre-compiled mex files for other platforms:
cd $HOME/matlab/tools/spm12_hmri
find . -name '*.mexw*' -delete
find . -name '*.mexmaci64' -delete
```

2. Download the hMRI toolbox (either the [original](https://github.com/hMRI-group/hMRI-toolbox/releases) or [our fork](https://github.com/MPIB/hMRI-toolbox) to a folder called `toolbox/hMRI` in an existing spm12 folder called `spm12_hmri/`.

Example:
```
cd $HOME/matlab/tools/spm12_hmri/toolbox
git clone https://github.com/hMRI-group/hMRI-toolbox hMRI
```

3. Fix overrides from hMRI

`spm_...` overrides in `toolbox/hMRI/` **must** be removed from the spm12 base
directory. The compiled archive cannot handle path prioririties properly.
Functions such as `spm_cfg_dicom` are then still taken from spm12 instead of
from hMRI. Keep in mind that this also means, the newly created `spm12_hmri/`
won't be functional without the hMRI toolbox.

```
cd $HOME/matlab/tools/spm12_hmri
for f in $(find toolbox/hMRI/spm12/ -iname 'spm_*'); do r=$(echo $f | cut -d"/" -f4-) ; if [ -f $r ] ; then rm $r ; fi ; done
cp toolbox/hMRI/spm12/spm_jsonread.mexa64 .
```

Build `run_spm12.sh` (with correct paths):

```
addpath('~/matlab/tools/spm12_hmri')
addpath('~/matlab/tools/spm12_hmri/config')
addpath(genpath('~/matlab/tools/spm12_hmri/toolbox/hMRI/'))
spm_make_standalone
```
