addpath('lib')
addpath(fullfile('lib', 'bids'))
setup_paths
warning('off', 'MATLAB:MKDIR:DirectoryExists');
log_file = start_log(fullfile(deriv_path, 'logs'), mfilename);
spm('defaults','FMRI');

subjects = get_subjects(nifti_path, 'full');
for i=1:length(subjects)
    subject = cell2mat(subjects(i));
    sessions = get_sessions(nifti_path, subject);
    for j=1:length(sessions)
        session = cell2mat(sessions(j));
        tmpid = get_tmpid_s();
        in_dir = fullfile(nifti_path, subject, session);
        out_dir = fullfile(deriv_path, 'MPM', subject, session);
        avg_pd = fullfile(spm_with_hmri, 'canonical', 'avg152PD.nii');
        avg_t1 = fullfile(spm_with_hmri, 'canonical', 'avg152T1.nii');
        mkdir(fullfile(out_dir, 'batches'));
        mkdir(fullfile(out_dir, 'logs'));
        mkdir(fullfile(out_dir, 'logs'));
        batchfile = fullfile(out_dir, 'batches', ['reorient-', tmpid, '.mat']);
        batchlog = fullfile(out_dir, 'logs', ['reorient-%j-', tmpid, '.log']);
        batchcmd = sprintf('%s %s batch %s', compiled_hmri, mcr_path, batchfile);
        files=cell(1,3);

        if exist(fullfile(out_dir, 'reorient_MT')) || ...
           exist(fullfile(out_dir, 'reorient_PD')) || ...
           exist(fullfile(out_dir, 'reorient_T1'))
            fprintf('Reorientation files already exist, skipping %s/%s\n', subject, session);
        else

            files{1} = spm_select('FPList', fullfile(in_dir, 'MT', 'magnitude'), '^.*\.nii$');
            files{2} = spm_select('FPList', fullfile(in_dir, 'PD', 'magnitude'), '^.*\.nii$');
            files{3} = spm_select('FPList', fullfile(in_dir, 'T1', 'magnitude'), '^.*\.nii$');


            fprintf('Creating batch for %s/%s ...\n', subject, session);
            matlabbatch = {};
            k = 1;
            if length(files{1})
                matlabbatch{k}.spm.tools.hmri.autoreor.reference = cellstr(files{1}(1,:));
                matlabbatch{k}.spm.tools.hmri.autoreor.template = cellstr(avg_pd);
                matlabbatch{k}.spm.tools.hmri.autoreor.other = cellstr(files{1});
                matlabbatch{k}.spm.tools.hmri.autoreor.output.outdir = {fullfile(out_dir, 'reorient_MT')};
                matlabbatch{k}.spm.tools.hmri.autoreor.dep = 'individual';
                k = k + 1;
            else
                fprintf('Skipping %s/%s for MT (missing)\n', subject, session);
            end

            if length(files{2})
                matlabbatch{k}.spm.tools.hmri.autoreor.reference = cellstr(files{2}(1,:));
                matlabbatch{k}.spm.tools.hmri.autoreor.template = cellstr(avg_pd);
                matlabbatch{k}.spm.tools.hmri.autoreor.other = cellstr(files{2});
                matlabbatch{k}.spm.tools.hmri.autoreor.output.outdir = {fullfile(out_dir, 'reorient_PD')};
                matlabbatch{k}.spm.tools.hmri.autoreor.dep = 'individual';
                k = k + 1;
            else
                fprintf('Skipping %s/%s for PD (missing)\n', subject, session);
            end

            if length(files{3})
                matlabbatch{k}.spm.tools.hmri.autoreor.reference = cellstr(files{3}(1,:));
                matlabbatch{k}.spm.tools.hmri.autoreor.template = cellstr(avg_t1);
                matlabbatch{k}.spm.tools.hmri.autoreor.other = cellstr(files{3});
                matlabbatch{k}.spm.tools.hmri.autoreor.output.outdir = {fullfile(out_dir, 'reorient_T1')};
                matlabbatch{k}.spm.tools.hmri.autoreor.dep = 'individual';
                k = k + 1;
            else
                fprintf('Skipping %s/%s for T1 (missing)\n', subject, session);
            end

            if length(matlabbatch)
                save(batchfile, 'matlabbatch');

                fprintf('Submitting\n');
                system(sprintf('sbatch -D. -c 1 -J %s -o %s --wrap "%s"', ...
                            ['reorient_', subject, '_', session], ...
                            batchlog, batchcmd));
            end
        end
    end % session
end % subject
stop_log(log_file);
